@@ -1,17 +1,16 @@
 class BigQuery:
     def p_expression_options(self, p):
-        """expr : expr multiple_options 
-        """
+        """expr : expr multiple_options"""
         p[0] = p[1]
         p[1].update(p[2])
-    
+
     def p_multiple_options(self, p):
         """multiple_options : options
         | multiple_options options
         """
-        print(list(p), '\n')
+        print(list(p), "\n")
         if len(p) > 2:
-            p[1]['options'].extend(p[2]['options'])
+            p[1]["options"].extend(p[2]["options"])
             p[0] = p[1]
         else:
             p[0] = p[1]
