@@ -32,6 +32,8 @@ common_statements = {
     "SALT": "SALT",
     "NO": "NO",
     "USING": "USING",
+    # bigquery
+    "OPTIONS": "OPTIONS",
 }
 
 columns_defenition = {
@@ -95,7 +97,7 @@ sequence_reserved = {
 
 tokens = tuple(
     set(
-        ["ID", "DOT", "STRING", "LP", "RP", "LT", "RT", "COMMAT"]
+        ["ID", "DOT", "STRING", "DQ_STRING", "LP", "RP", "LT", "RT", "COMMAT"]
         + list(defenition_statements.values())
         + list(common_statements.values())
         + list(columns_defenition.values())
